<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et_EE">
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/entity/RArcEntity.cpp" line="+95"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+79"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+157"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="+152"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+81"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Keskus</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="-2"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="+164"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-2"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="+154"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="+156"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="+117"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-2"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="+121"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+75"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+97"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+84"/>
        <location line="+4"/>
        <location line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+90"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+88"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+78"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+108"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+78"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+75"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+90"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RToleranceEntity.cpp" line="+82"/>
        <location line="+3"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+75"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+82"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+78"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-15"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-6"/>
        <location line="+4"/>
        <location line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-5"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-16"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RToleranceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-15"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-6"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-5"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-16"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RToleranceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Middle</source>
        <translation>Keskpunkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <source>Radius</source>
        <translation>Radius</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-9"/>
        <source>Start Angle</source>
        <translation>Algusnurk</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>End Angle</source>
        <translation>Lõppnurk</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>Reversed</source>
        <translation>Ümberpööratud</translation>
    </message>
    <message>
        <location line="+2"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+2"/>
        <source>Diameter</source>
        <translation>Läbimõõt</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+9"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+2"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+7"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+3"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+10"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+2"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-11"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+2"/>
        <source>Length</source>
        <translation>Pikkus</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <source>Total Length</source>
        <translation>Kogupikkus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sweep Angle</source>
        <translation>Pühkimisnurk</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+2"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+3"/>
        <source>Area</source>
        <translation>Piirkond</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <source>Total Area</source>
        <translation>Kogupindala</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeDefinitionEntity.cpp" line="+93"/>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+102"/>
        <source>Invisible</source>
        <translation>Nähtamatu</translation>
    </message>
    <message>
        <location line="+2"/>
        <location filename="../src/entity/RAttributeEntity.cpp" line="-1"/>
        <source>Tag</source>
        <translation>Silt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prompt</source>
        <translation>Prompt</translation>
    </message>
    <message>
        <location filename="../src/entity/RCircleEntity.cpp" line="-2"/>
        <source>Circumference</source>
        <translation>Ümbermõõt</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 Start</source>
        <translation>Rea 1 algus</translation>
    </message>
    <message>
        <location line="+10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 Start</source>
        <translation>Rea 2 algus</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 End</source>
        <translation>Rida 1 Lõpp</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 End</source>
        <translation>Rida 2 lõpp</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Arc</source>
        <translation>Mõõdukaar</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="+190"/>
        <source>Arc Symbol Type</source>
        <translation>Kaare sümboli tüüp</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-6"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Chord Point</source>
        <translation>Akordi punkt</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Far Chord Point</source>
        <translation>Kaugse akordi punkt</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Line</source>
        <translation>Dimensiooni rida</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 1</source>
        <translation>Pikenduspunkt 1</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 2</source>
        <translation>Pikenduspunkt 2</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-11"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Päritolu</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate</source>
        <translation>Ordinaat</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Defining Point</source>
        <translation>Määratluspunkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Leader End Point</source>
        <translation>Leader lõpp-punkt</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimRotatedEntity.cpp" line="+172"/>
        <source>Dimension Angle</source>
        <translation>Mõõdus nurk</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-8"/>
        <source>Label</source>
        <translation>Silt</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Tolerance</source>
        <translation>Sallivus</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Upper Limit</source>
        <translation>Ülempiir</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Lower Limit</source>
        <translation>Alumine piir</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Definition Point</source>
        <translation>Määratluspunkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Teksti asukoht</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Text Rotation</source>
        <translation>Teksti pööramine</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Flip First Arrow</source>
        <translation>Flip esimene nool</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Flip Second Arrow</source>
        <translation>Flip teine nool</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Fixed Extension Line</source>
        <translation>Fikseeritud pikendusliin</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension Line Length</source>
        <translation>Pikendusliini pikkus</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Auto Label</source>
        <translation>Automaatne etikett</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Measured Value</source>
        <translation>Mõõdetud väärtus</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Block Name</source>
        <translation>Ploki nimi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Auto Label Position</source>
        <translation>Automaatne sildi asukoht</translation>
    </message>
    <message>
        <location filename="../src/entity/REllipseEntity.cpp" line="-17"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Major Point</source>
        <translation>Major Point</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ratio</source>
        <translation>Suhtarv</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start Parameter</source>
        <translation>Start parameeter</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Parameter</source>
        <translation>Lõpuparameeter</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-12"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Point</source>
        <translation>Startpunkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+4"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Point</source>
        <translation>Lõpp-punkt</translation>
    </message>
    <message>
        <location filename="../src/entity/RFaceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 1</source>
        <translation>Punkt 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 2</source>
        <translation>Punkt 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 3</source>
        <translation>Punkt 3</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 4</source>
        <translation>Punkt 4</translation>
    </message>
    <message>
        <location filename="../src/entity/RHatchEntity.cpp" line="-10"/>
        <source>Solid</source>
        <translation>Soliidne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Winding</source>
        <translation>Tuulestik</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Alpha</source>
        <translation>Alpha</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Muster</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>From Entity</source>
        <translation>Üksuselt</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+14"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-13"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+2"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <source>Angle</source>
        <translation>Nurk</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Scale</source>
        <translation>Skaala</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+2"/>
        <location line="+1"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Vertex</source>
        <translation>Vertex</translation>
    </message>
    <message>
        <location line="+201"/>
        <source>Yes</source>
        <translation>Jah</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>No</source>
        <translation>Ei</translation>
    </message>
    <message>
        <location filename="../src/entity/RImageEntity.cpp" line="-18"/>
        <source>File</source>
        <translation>Faili</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPointEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Positsioon</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>U</source>
        <translation>U</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width Factor</source>
        <translation>Laiuse tegur</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height Factor</source>
        <translation>Kõrguse tegur</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width</source>
        <translation>Laius</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height</source>
        <translation>Kõrgus</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Fade</source>
        <translation>Fade</translation>
    </message>
    <message>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-5"/>
        <source>Arrow</source>
        <translation>Noolega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Spline</source>
        <translation>Spline</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow Block</source>
        <translation>Nooleplokk</translation>
    </message>
    <message>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-9"/>
        <source>Polyline Pattern</source>
        <translation>Polüjoone muster</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Closed</source>
        <translation>Suletud</translation>
    </message>
    <message>
        <location line="+4"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+0"/>
        <source>Bulge</source>
        <translation>Bulge</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Start Width</source>
        <translation>Algus Laius</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Width</source>
        <translation>Lõpp Laius</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Width</source>
        <translation>Ülemaailmne laius</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orientation</source>
        <translation>Orienteerumine</translation>
    </message>
    <message>
        <location line="+9"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Suurus</translation>
    </message>
    <message>
        <location line="-2"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="-2"/>
        <source>Base Angle</source>
        <translation>Alusnurk</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
        <source>Size 1</source>
        <translation>Suurus 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
        <source>Size 2</source>
        <translation>Suurus 2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Z</source>
        <translation>Globaalne Z</translation>
    </message>
    <message>
        <location filename="../src/entity/RRayEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Base Point</source>
        <translation>Baaspunkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Second Point</source>
        <translation>Teine punkt</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Direction Vector</source>
        <translation>Suunavektor</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+3"/>
        <source>Fixed Angle</source>
        <translation>Fikseeritud nurk</translation>
    </message>
    <message>
        <location filename="../src/entity/RSplineEntity.cpp" line="-12"/>
        <source>Closed Periodic</source>
        <translation>Suletud Perioodiline</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translation>Kraad</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Control Point</source>
        <translation>Kontrollpunkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Fit Point</source>
        <translation>Fit Point</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Knot Vector</source>
        <translation>Sõlm Vektor</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Knot</source>
        <translation>Sõlm</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use Start Tangent</source>
        <translation>Kasutage Start Tangent</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Tangent</source>
        <translation>Start Tangent</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use End Tangent</source>
        <translation>Kasutage End Tangenti</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Tangent</source>
        <translation>Lõpp Tangent</translation>
    </message>
    <message>
        <location filename="../src/entity/RToleranceEntity.cpp" line="-5"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Location</source>
        <translation>Asukoht</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Direction</source>
        <translation>Suund</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../src/entity/RLineEntity.cpp" line="-7"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Middle Point</source>
        <translation>Keskpunkt</translation>
    </message>
    <message>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+2"/>
        <source>Frame</source>
        <translation>Raam</translation>
    </message>
</context>
</TS>
